@@ -1,26 +1,19 @@
 # -*- coding: utf-8 -*-
 """
-MIT License
+  Copyright 2022 Mitchell Isaac Parker
 
-Copyright (c) 2022 Mitchell Isaac Parker
+   Licensed under the Apache License, Version 2.0 (the "License");
+   you may not use this file except in compliance with the License.
+   You may obtain a copy of the License at
 
-Permission is hereby granted, free of charge, to any person obtaining a copy
-of this software and associated documentation files (the "Software"), to deal
-in the Software without restriction, including without limitation the rights
-to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-copies of the Software, and to permit persons to whom the Software is
-furnished to do so, subject to the following conditions:
+       http://www.apache.org/licenses/LICENSE-2.0
 
-The above copyright notice and this permission notice shall be included in all
-copies or substantial portions of the Software.
+   Unless required by applicable law or agreed to in writing, software
+   distributed under the License is distributed on an "AS IS" BASIS,
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   See the License for the specific language governing permissions and
+   limitations under the License.
 
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-SOFTWARE.
 """
 
 import math
@@ -44,6 +37,11 @@ from .col import (
     altchi2_col,
 )
 
+p_rot = 'p'
+m_rot = 'm'
+t_rot = 't'
+n_rot = '-'
+
 bb_dict = {
     phi_col: [["C", "N", "CA", "C"], [-1, 0, 0, 0]],
     psi_col: [["N", "CA", "C", "N"], [0, 0, 0, 1]],
@@ -165,13 +163,13 @@ def get_rot_type(rot):
     rot = float(rot)
 
     if rot == 999.00:
-        return "-"
+        return n_rot
     elif 0 <= rot < 120:
-        return "p"
+        return p_rot
     elif 120 <= rot < 240:
-        return "t"
+        return t_rot
     elif 240 <= rot < 360:
-        return "m"
+        return m_rot 
 
 
 def calc_dih_angle(
